@@ -7,7 +7,7 @@ package Sub::HandlesVia;
 use Exporter::Shiny qw( delegations );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.019';
+our $VERSION   = '0.020';
 
 sub _generate_delegations {
 	my ($me, $name, $args, $globals) = (shift, @_);
@@ -478,6 +478,11 @@ native traits, and L<MouseX::NativeTraits>.
                   gt : SubHV                       
                   ge : SubHV                       
  
+  Scalar ==========================================
+         make_getter : SubHV                       
+         make_setter : SubHV                       
+    scalar_reference : SubHV                       
+ 
   String ==========================================
               append : SubHV  DataP  Moose  Mouse  
                chomp : SubHV  DataP  Moose  Mouse  
