@@ -5,7 +5,7 @@ use warnings;
 package Sub::HandlesVia::Handler;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.019';
+our $VERSION   = '0.020';
 
 use Class::Tiny (
 	qw(
@@ -27,6 +27,7 @@ use Class::Tiny (
 		min_args     => sub { shift->args },
 		max_args     => sub { shift->args },
 		usage        => sub { shift->_build_usage },
+		allow_getter_shortcuts => sub { 1 },
 	},
 );
 sub has_min_args { defined shift->min_args }
@@ -176,7 +177,8 @@ sub _process_template {
 			[\]\}]          #     closing ] or }
 		){0,3}             # ... up to thrice
 		$/x
-		and $template =~ /\$GET/) {
+		and $template =~ /\$GET/
+		and $self->allow_getter_shortcuts) {
 		# Getter is kind of complex (maybe includes function calls, etc
 		# So only do it once.
 		$getter =~ s/%/%%/g;
@@ -394,7 +396,7 @@ sub _generate_handler {
 package Sub::HandlesVia::Handler::Traditional;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.019';
+our $VERSION   = '0.020';
 
 BEGIN { our @ISA = 'Sub::HandlesVia::Handler' };
 
@@ -437,7 +439,7 @@ sub _coderef {
 package Sub::HandlesVia::Handler::CodeRef;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.019';
+our $VERSION   = '0.020';
 
 BEGIN { our @ISA = 'Sub::HandlesVia::Handler' };
 
