@@ -5,7 +5,7 @@ use warnings;
 package Sub::HandlesVia::HandlerLibrary::Array;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.019';
+our $VERSION   = '0.020';
 
 use Sub::HandlesVia::HandlerLibrary;
 our @ISA = 'Sub::HandlesVia::HandlerLibrary';
@@ -138,9 +138,9 @@ sub is_empty {
 			my ( $class, $attr, $method ) = @_;
 			return CORE::join "",
 				"  my \$object = $class\->new( $attr => [ 'foo', 'bar' ] );\n",
-				"  say \$object->$method; ## ==> 0\n",
+				"  say \$object->$method; ## ==> false\n",
 				"  \$object->_set_$attr( [] );\n",
-				"  say \$object->$method; ## ==> 1\n",
+				"  say \$object->$method; ## ==> true\n",
 				"\n";
 		},
 }
@@ -429,7 +429,7 @@ sub accessor {
 			"  my \$object = $class\->new( $attr => [ 'foo', 'bar', 'baz' ] );\n",
 			"  \$object->$method( 1, 'quux' );\n",
 			"  say Dumper( \$object->$attr ); ## ==> [ 'foo', 'quux', 'baz' ]\n",
-			"  \$object->$method( 2 ); ## ==> 'baz'\n",
+			"  say \$object->$method( 2 ); ## ==> 'baz'\n",
 			"\n";
 	},
 }
@@ -666,7 +666,7 @@ sub insert {
 			return CORE::join "",
 				"  my \$object = $class\->new( $attr => [ 'foo', 'bar', 'baz' ] );\n",
 				"  \$object->$method( 1, 'quux' );\n",
-				"  say \$object->$attr; ## ==> [ 'foo', 'quux', 'bar', 'baz' ]\n",
+				"  say Dumper( \$object->$attr ); ## ==> [ 'foo', 'quux', 'bar', 'baz' ]\n",
 				"\n";
 		},
 }
@@ -779,7 +779,7 @@ sub for_each {
 			my ( $class, $attr, $method ) = @_;
 			return CORE::join "",
 				"  my \$object = $class\->new( $attr => [ 'foo', 'bar', 'baz' ] );\n",
-				"  \$object->$method(sub { say \"Item \$_[1] is \$_[0].\" });\n",
+				"  \$object->$method( sub { say \"Item \$_[1] is \$_[0].\" } );\n",
 				"\n";
 		},
 }
