@@ -5,7 +5,7 @@ use warnings;
 package Sub::HandlesVia::HandlerLibrary::Code;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.019';
+our $VERSION   = '0.020';
 
 use Sub::HandlesVia::HandlerLibrary;
 our @ISA = 'Sub::HandlesVia::HandlerLibrary';
@@ -22,7 +22,7 @@ sub execute {
 		_examples => sub {
 			my ( $class, $attr, $method ) = @_;
 			return join "",
-				"  my \$coderef = sub { ... };\n",
+				"  my \$coderef = sub { 'code' };\n",
 				"  my \$object  = $class\->new( $attr => \$coderef );\n",
 				"  \n",
 				"  # \$coderef->( 1, 2, 3 )\n",
@@ -40,7 +40,7 @@ sub execute_method {
 		_examples => sub {
 			my ( $class, $attr, $method ) = @_;
 			return join "",
-				"  my \$coderef = sub { ... };\n",
+				"  my \$coderef = sub { 'code' };\n",
 				"  my \$object  = $class\->new( $attr => \$coderef );\n",
 				"  \n",
 				"  # \$coderef->( \$object, 1, 2, 3 )\n",
